[PATCH 3/6] Cochran high baud rate download seemed to fail after 2.5MB or so resulting in short, failed reads of several hundred bytes. Trying 806400 baud instead of 825600.

John Van Ostrand john at vanostrand.com
Mon Jan 11 07:22:55 PST 2016


---
 src/cochran_commander.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/cochran_commander.c b/src/cochran_commander.c
index 8bb61c9..9328aaa 100644
--- a/src/cochran_commander.c
+++ b/src/cochran_commander.c
@@ -74,7 +74,7 @@ static cochran_layout_t cochran_layout_emc20 = {
 	 ENDIAN_LE,			/* endian */
 	 DATE_SMHDMY,		/* date_format */
 	 ADDRESS_32_BIT,	/* address_size */
-	 825600,			/* high_baud_rate */
+	 806400,			/* high_baud_rate was 825600 */
 
 	 0x00000000,		/* rb_logbook_begin */
 	 0x00080000,		/* rb_logbook_end */
@@ -97,7 +97,7 @@ static cochran_layout_t cochran_layout_emc16 = {
 	 ENDIAN_LE,			/* endian */
 	 DATE_SMHDMY,		/* date_format */
 	 ADDRESS_32_BIT,	/* address_size */
-	 825600,			/* high_baud_rate */
+	 806400,			/* high_baud_rate */
 
 	 0x00000000,		/* rb_logbook_begin */
 	 0x00080000,		/* rb_logbook_end */
@@ -120,7 +120,7 @@ static cochran_layout_t cochran_layout_emc14 = {
 	 ENDIAN_LE,			/* endian */
 	 DATE_SMHDMY,		/* date_format */
 	 ADDRESS_32_BIT,	/* address_size */
-	 825600,			/* high_baud_rate */
+	 806400,			/* high_baud_rate */
 
 	 0x00000000,		/* rb_logbook_begin */
 	 0x00020000,		/* rb_logbook_end */
@@ -183,7 +183,7 @@ cochran_packet (cochran_device_t *device, dc_event_progress_t *progress,
 	if (high_speed) {
 		serial_sleep(device->port, 45);
 
 		// Rates are odd, like 825600 for the EMC, 115200 for commander
 		cochran_layout_t *layout = cochran_commander_get_layout(device->model_string);
 		rc = serial_configure(device->port, layout->high_baud_rate, 8,
 						SERIAL_PARITY_NONE, 2, SERIAL_FLOWCONTROL_NONE);
@@ -183,7 +183,7 @@ cochran_packet (cochran_device_t *device, dc_event_progress_t *progress,
 		serial_sleep(device->port, 45);
 
-		// Rates are odd, like 825600 for the EMC, 115200 for commander
+		// Rates are odd, like 806400 for the EMC, 115200 for commander
 		cochran_layout_t *layout = cochran_commander_get_layout(device->model_string);
 		rc = serial_configure(device->port, layout->high_baud_rate, 8,
-- 
2.4.3



More information about the devel mailing list